@@ -28,11 +28,11 @@ __license__   = "LGPL"
 
 # $ORCA_MAJOR_VERSION.$ORCA_MINOR_VERSION.$ORCA_MICRO_VERSION
 #
-version     = "3.1.2"
+version     = "3.1.4"
 
 # "--prefix" parameter used when configuring the build.
 #
-prefix      = "/home/jd/orca/bld"
+prefix      = "/home/aleiva/work/gnome/orca-new-release/bld"
 
 # The package name (should be "orca").
 #
@@ -44,4 +44,4 @@ datadirname = "share"
 
 # The directory where we could find liblouis translation tables.
 #
-tablesdir = "/usr/share/liblouis/tables"
+tablesdir = ""
